# NewAnimepy
An anime crawler for [anigamer](https://ani.gamer.com.tw/)

## Installation

## Usage
You can use it to get new anime and search result of anigamer
For more info, you can see [example.py](https://github.com/z20030818/NewAnimepy/blob/main/animepy/examples/example.py)

## License
MIT © [z20030818](https://github.com/z20030818/NewAnimepy/blob/main/LICENSE)